"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _got = _interopRequireDefault(require("got"));

var _toughCookie = require("tough-cookie");

var _serializeError = require("serialize-error");

var _httpProxyAgent = _interopRequireDefault(require("http-proxy-agent"));

var _httpsProxyAgent = _interopRequireDefault(require("https-proxy-agent"));

var _routines = require("../routines");

var _Logger = _interopRequireDefault(require("../Logger"));

var _createToughCookiePayloadFromPuppeteerCookies = _interopRequireDefault(require("./createToughCookiePayloadFromPuppeteerCookies"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = _Logger.default.child({
  namespace: 'createPageProxy'
});

const defaultChromeHeaders = {
  accept: 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
  'accept-encoding': 'gzip, deflate, br',
  'accept-language': 'en'
};
/**
 * @see https://github.com/puppeteer/puppeteer/issues/5364
 */

const appendDefaultChromeHeaders = request => {
  let nextHeaders = { ...request.headers(),
    ...defaultChromeHeaders,
    host: new URL(request.url()).hostname
  };

  if (request.isNavigationRequest()) {
    nextHeaders = { ...nextHeaders,
      'sec-fetch-mode': 'navigate',
      'sec-fetch-site': 'none',
      'sec-fetch-user': '?1'
    };
  } else {
    nextHeaders = { ...nextHeaders,
      'sec-fetch-mode': 'no-cors',
      'sec-fetch-site': 'same-origin'
    };
  }

  return nextHeaders;
};

const createPageProxy = pageProxyConfiguration => {
  const page = pageProxyConfiguration.page;

  const proxyRequest = async proxyRequestConfiguration => {
    const {
      proxyUrl,
      request
    } = proxyRequestConfiguration;
    const headers = appendDefaultChromeHeaders(request);
    log.debug({
      body: request.postData(),
      headers,
      method: request.method(),
      url: request.url()
    }, 'making a request using HTTP proxy');

    const cookieJar = _toughCookie.CookieJar.deserializeSync((0, _createToughCookiePayloadFromPuppeteerCookies.default)((await (0, _routines.getAllCookies)(page)).cookies));

    let agent;

    if (proxyRequestConfiguration.agent) {
      agent = proxyRequestConfiguration.agent;
    } else if (proxyUrl && request.url().toLowerCase().startsWith('https://')) {
      agent = new _httpsProxyAgent.default(proxyUrl);
    } else if (proxyUrl) {
      agent = new _httpProxyAgent.default(proxyUrl);
    }

    let response;

    try {
      response = await (0, _got.default)(request.url(), {
        agent,
        body: request.postData(),
        cookieJar,
        followRedirect: false,
        headers,
        method: request.method(),
        responseType: 'buffer',
        retry: 0,
        throwHttpErrors: false
      });
    } catch (error) {
      log.error({
        error: (0, _serializeError.serializeError)(error)
      }, 'could not complete HTTP request due to an error');
      request.abort();
      return;
    }

    if (!response) {
      throw new Error('response object is not present.');
    }

    await request.respond({
      body: response.body,
      headers: response.headers,
      status: response.statusCode
    });
  };

  return {
    proxyRequest: async configuration => {
      try {
        await proxyRequest(configuration);
      } catch (error) {
        log.error({
          error: (0, _serializeError.serializeError)(error)
        }, 'could not proxy request due to an error');
        configuration.request.abort();
      }
    }
  };
};

var _default = createPageProxy;
exports.default = _default;
//# sourceMappingURL=createPageProxy.js.map